.. _gal-simulation:

Simuation and Visualization
===========================

This section provides examples of how to run simulations using the main :ref:`api-simulation` component of Cratermaker to emplace craters on a surface and visualize the results with various tools.
